@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 3.0.0 (2021-11-21)
+   Version: 3.0.1 (2021-11-22)
    Website: http://www.gingerblue.org/
 
  */
@@ -68,6 +68,9 @@ GstTagList *tag_list;
 
 GError *error = NULL;
 
+gchar *htmlfile = NULL;
+gchar *htmlfp = NULL;
+
 static void gb_assistant_entry_changed(GtkEditable * editable,
 				       GtkAssistant * assistant,
 				       GstElement * pipeline)
@@ -110,9 +113,24 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			       gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
-			       g_date_time_format_iso8601 (datestamp),
+			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"),
 			       "]",
 			       ".ogg", NULL);
+	htmlfile = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			       gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
+			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"),
+			       "]",
+			       ".html", NULL);
+	htmlfp = fopen(htmlfile, "w");
+	fprintf(htmlfp, "<html>\n  <head>\n    <title>%s - %s</title>\n  </head>\n  <body>\n    <h1>%s</h1>\n", gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)), gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	fprintf(htmlfp, "<h2><a href='http://wiki.gnome.org/Apps/Gingerblue'>Gingerblue 3.0.1</a></h2>\n");
+	fprintf(htmlfp, "<p><a href='%s'>%s</a> (Ogg Vorbis, 48kHz, Mono)",
+		gtk_entry_get_text(GTK_ENTRY(recording_entry)),
+		g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
+			    "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			    gtk_entry_get_text(GTK_ENTRY(song_entry)),
+			    ".ogg", NULL));
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
 				 "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
@@ -168,9 +186,16 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 	    g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
-			g_date_time_format_iso8601 (datestamp), "]",
+			g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
 			".gingerblue", NULL);
-	fp = fopen(filename, "w");
+	gchar *htmlfile = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
+			g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
+			".html", NULL);
+
+	htmlfp = fopen(htmlfile, "a+");
+	fprintf(fp, "<p><a href='%s'>%s (%s)</a></p>", filename, gtk_entry_get_text(GTK_ENTRY(musician_entry)), gtk_entry_get_text(GTK_ENTRY(instrument_entry)));
 	fprintf(fp, "<?xml version='1.0' encoding='UTF-8'?>\n");
 	fprintf(fp, "<gingerblue version='%s'>\n", VERSION);
 	fprintf(fp, "  <musician>%s</musician>\n",
@@ -271,7 +296,7 @@ int main(int argc, char **argv)
 	gchar *filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 				      gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				      gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
-				      g_date_time_format_iso8601 (datestamp), "]",
+				      g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
 				      ".ogg", NULL);
 	gtk_init(&argc, &argv);
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -292,7 +317,7 @@ int main(int argc, char **argv)
 	page[2].widget = gtk_box_new(FALSE, 5);
 	song_label = gtk_label_new(_("Song:"));
 	song_entry = gtk_entry_new();
-	if (g_strcmp0(song_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song_-_"), g_date_time_format_iso8601 (datestamp), NULL)); else gtk_entry_set_text(GTK_ENTRY(song_entry), gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	if (g_strcmp0(song_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song_-_"), g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), NULL)); else gtk_entry_set_text(GTK_ENTRY(song_entry), gtk_entry_get_text(GTK_ENTRY(song_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_entry),
@@ -491,7 +516,7 @@ int main(int argc, char **argv)
 	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 			       gtk_entry_get_text(GTK_ENTRY(song_entry)),"_[",
-			       g_date_time_format_iso8601 (datestamp), "]",
+			       g_date_time_format (datestamp, "%Y-%m-%dT%H:%M:%S"), "]",
 			       ".ogg", NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
@@ -538,6 +563,11 @@ int main(int argc, char **argv)
 	fprintf(xspf, "</playlist>\n");
 	fclose(xspf);
 
+	htmlfp = fopen(htmlfile, "a+");
+	htmlfp = fprintf(htmlfp, "<p>XSPF: <a href='%s'>%s</a></p>", g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL));
+	fprintf(htmlfp, "  </body>\n</html>\n");
+	fclose(htmlfp);
+
 	gtk_main();
 	return (0);
 }
